<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://club.wpeka.com/
 * @since      1.0.0
 *
 * @package    Wpadcenter
 * @subpackage Wpadcenter/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Wpadcenter
 * @subpackage Wpadcenter/public
 * @author     WPEka Club <support@wpeka.com>
 */
class Wpadcenter_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of the plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
		if ( ! shortcode_exists( 'wpadcenter' ) ) {
			add_shortcode( 'wpadcenter', array( $this, 'wpadcenter_shortcode' ) );
		}

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wpadcenter_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wpadcenter_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_register_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/wpadcenter-public' . WPADCENTER_SCRIPT_SUFFIX . '.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Wpadcenter_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Wpadcenter_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_register_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/wpadcenter-public' . WPADCENTER_SCRIPT_SUFFIX . '.js', array( 'jquery' ), $this->version, false );

	}

	/**
	 * Shortcode display for WP AdCenter.
	 *
	 * @since 1.0.0
	 * @param Array $atts Shortcode attributes.
	 * @return false|string|void
	 */
	public function wpadcenter_shortcode( $atts ) {
		if ( is_admin() ) {
			return;
		}
		$atts = shortcode_atts(
			array(
				'id' => 0,
			),
			$atts
		);
		if ( isset( $atts['id'] ) && 0 !== $atts['id'] ) {
			ob_start();
			$container_styles = '';
			$message          = '';
			$adzone_id        = $atts['id'];
			$the_options      = Wpadcenter::wpadcenter_get_settings();
			$geo_location     = $the_options['geo_location'];
			$auto_refresh     = $the_options['auto_refresh'];
			if ( $auto_refresh ) {
				$transition = $the_options['transition_effect'];
				$speed      = $the_options['transition_speed'];
				$delay      = $the_options['transition_delay'];
			}
			$numberofposts     = -1;
			$container_styles .= 'width:100%;height:auto;margin:0;padding:0;';
			$adzone_display    = false;
			if ( 'adzone' === $geo_location && get_option( 'wpadcenter_pro_active' ) ) {
				$adzone_geo_countries = get_field( 'adzones_geolocation_countries', $adzone_id );
				if ( $adzone_geo_countries ) {
					$geo_country = Wpadcenter::wpadcenter_get_geo_country_code();
					if ( in_array( $geo_country, $adzone_geo_countries, true ) || in_array( 'all', $adzone_geo_countries, true ) ) {
						$adzone_display = true;
					}
				} else {
					$adzone_display = true;
				}
			} else {
				$adzone_display = true;
			}
			if ( $adzone_display ) {
				if ( ! $auto_refresh ) {
					$auto_refresh = get_field( 'auto_refresh_ads', $adzone_id );
					$transition   = get_field( 'transition_effect', $adzone_id );
					$speed        = get_field( 'transition_speed', $adzone_id );
					$delay        = get_field( 'transition_delay', $adzone_id );
				}
				$adzone_default_banner = get_field( 'default_banner', $adzone_id );
				$adzone_signup_link    = get_field( 'signup_link', $adzone_id );
				$adzone_template       = get_field( 'template', $adzone_id );
				$adzone_text_above     = get_field( 'text_above_ad_zone', $adzone_id );
				$adzone_text_below     = get_field( 'text_below_ad_zone', $adzone_id );
				$adzone_size           = explode( 'x', $adzone_template );
				$width                 = $adzone_size['0'];
				$height                = $adzone_size['1'];
				$adzone_rows           = get_field( 'horizontal', $adzone_id );
				$adzone_columns        = get_field( 'vertical', $adzone_id );
				$adzone_classes        = 'adzone_1_1';
				if ( $adzone_rows && $adzone_columns && ! $auto_refresh ) {
					$adzone_classes = 'adzone_' . $adzone_rows . '_' . $adzone_columns;
					$numberofposts  = $adzone_columns * $adzone_rows;
				}
				$args      = array(
					'post_type'   => 'wpadcenter-campaigns',
					'post_status' => 'adc-running',
					'numberposts' => -1,
				);
				$campaigns = get_posts( $args );
				if ( $campaigns ) {
					$campaign_ids = array();
					foreach ( $campaigns as $campaign ) {
						$campaign_id = $campaign->ID;
						if ( 'campaign' === $geo_location && get_option( 'wpadcenter_pro_active' ) ) {
							$campaign_geo_countries = get_field( 'campaigns_geolocation_countries', $campaign->ID );
							if ( $campaign_geo_countries ) {
								$geo_country = Wpadcenter::wpadcenter_get_geo_country_code();
								if ( in_array( $geo_country, $campaign_geo_countries, true ) || in_array( 'all', $campaign_geo_countries, true ) ) {
									$campaign_ids[] = $campaign_id;
								}
							} else {
								$campaign_ids[] = $campaign_id;
							}
						} else {
							$campaign_ids[] = $campaign_id;
						}
					}
					if ( empty( $campaign_ids ) ) {
						$campaign_ids = '';
					}
					$args    = array(
						'post_type'   => 'wpadcenter-banners',
						'post_status' => 'publish',
						'numberposts' => $numberofposts,
						'meta_query'  => array( // phpcs:ignore slow query
							'relation' => 'AND',
							array(
								'key'     => 'banners_campaign',
								'value'   => $campaign_ids,
								'compare' => 'IN',
							),
							array(
								'key'     => 'banners_ad_zone',
								'value'   => $adzone_id,
								'compare' => '=',
							),
						),
					);
					$banners = get_posts( $args );
					if ( $banners ) {
						$message  = apply_filters( 'wpadcenter_block_render_before', $message );
						$message .= '<div class="wpadcenter-text-above">' . $adzone_text_above . '</div>';
						if ( $auto_refresh ) {
							$container_styles .= 'max-width:' . $width . 'px;';
							$message          .= '<div class="wpadcenter-slider cycle-slideshow" data-slides="div.wpadcenter-slide" data-cycle-fx="' . $transition . '" data-cycle-speed="' . $speed . '" data-cycle-delay="' . $delay . '">';
						} else {
							$message .= '<div class="wpadcenter-slider">';
						}
						foreach ( $banners as $banner ) {
							$banner_id          = $banner->ID;
							$banner_link_url    = get_field( 'link_url', $banner_id );
							$banner_link_target = get_field( 'link_target', $banner_id );
							$banner_advertiser  = get_field( 'banners_advertiser', $banner_id );
							$banner_campaign    = get_field( 'banners_campaign', $banner_id );
							$banner_ad_zone     = get_field( 'banners_ad_zone', $banner_id );
							$banner_type        = get_field( 'banner_type', $banner_id );
							$message           .= '<div class="wpadcenter-slide ' . $adzone_classes . '">';
							if ( get_option( 'wpadcenter_pro_active' ) ) {
								$message .= '<input type="hidden" name="banner_id" value="' . $banner_id . '">';
								$message .= '<input type="hidden" name="banner_advertiser" value="' . $banner_advertiser . '">';
								$message .= '<input type="hidden" name="banner_campaign" value="' . $banner_campaign . '">';
								$message .= '<input type="hidden" name="banner_ad_zone" value="' . $banner_ad_zone . '">';
							}
							$message .= '<a href="' . $banner_link_url . '" target="' . $banner_link_target . '">';
							switch ( $banner_type ) {
								case 'image':
									$banner_img = get_field( 'image', $banner_id );
									$banner_img = wp_get_attachment_image( $banner_img, $width, $height );
									$message   .= $banner_img;
									break;
								case 'external_image_link':
									$banner_img_link = get_field( 'image_link', $banner_id );
									$message        .= '<img width="' . $width . '" height="' . $height . '" src="' . esc_url( $banner_img_link ) . '"/>';
									break;
								case 'ad_code':
									$banner_ad_code = get_field( 'ad_code', $banner_id );
									$message       .= '<span class="wpadcenter-ad-code">' . $banner_ad_code . '</span>';
									break;
							}
							$message .= '</a>';
							$message .= '</div>';
						}
						$message .= '</div>';
						$message .= '<div class="wpadcenter-text-below">' . $adzone_text_below . '</div>';
					} else {
						if ( $adzone_default_banner ) {
							$message           .= '<a href="' . $adzone_signup_link . '" target="_blank">';
							$default_banner_img = wp_get_attachment_image( $adzone_default_banner, $width, $height );
							$message           .= $default_banner_img;
							$message           .= '</a>';
						}
					}
				} else {
					if ( $adzone_default_banner ) {
						$message           .= '<a href="' . $adzone_signup_link . '" target="_blank">';
						$default_banner_img = wp_get_attachment_image( $adzone_default_banner, $width, $height );
						$message           .= $default_banner_img;
						$message           .= '</a>';
					}
				}
			}
			?>
			<div class="wpadcenter-block-container" style="<?php echo $container_styles; ?>"><?php echo $message; ?></div> <?php // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
			<?php
			return ob_get_clean();
		}
	}

}
